@@ -1,7 +1,8 @@
-from __future__ import absolute_import
+# Copyright (c) 2016, The Regents of the University of California.
 
+from __future__ import absolute_import
 from . import DBConstants
-from .screedRecord import Record, _Writer
+from .screedRecord import Record
 from .utils import to_str
 
 FieldTypes = (('name', DBConstants._INDEXED_TEXT_KEY),
@@ -18,7 +19,7 @@ def fasta_iter(handle, parse_description=False, line=None):
         line = handle.readline()
 
     while line:
-        data = Record()
+        data = {}
 
         line = to_str(line.strip())
         if not line.startswith('>'):
@@ -45,12 +46,4 @@ def fasta_iter(handle, parse_description=False, line=None):
             line = to_str(handle.readline())
 
         data['sequence'] = ''.join(sequenceList)
-        yield data
-
-
-class FASTA_Writer(_Writer):
-
-    def write(self, record):
-        s = ">%s %s\n%s\n" % (record.name, record.description,
-                              record.sequence,)
-        self.fp.write(s)
+        yield Record(**data)
